==> go.php?file=RaidAchievement1.128.zip: RaidAchievement/Localization/localization-ptBR.lua <==
﻿if GetLocale() == "ptBR" then

function psealocale()

	charakillintime = "Requerimentos completos! Mate o chefe com 3 stacks de Carga Elétrica (30 seg restando)!" -- Needs review
	charakillintime2 = "Requerimentos completos! Acabe com o chefe agora enquanto ele está com o buff (20 seg restantes)!" -- Needs review
	-- chhrbrannyell = ""
	chratitle = "Cataclysm Heróico" -- Needs review
	crraraidpartachloc1 = "Choque Estático!" -- Needs review
	crraraidpartachloc2 = "Bomba de Veneno!" -- Needs review
	crraraidpartachloc3 = "Aniquilador Arcano!" -- Needs review
	crraraidpartachloc4 = "Lança-chamas!" -- Needs review
	crratitle = "Raides do Cataclysm" -- Needs review
	icratitle = "cidadela da coroa de gelo" -- Needs review
	icravalitriayell1 = "Eu abri um portal para o Sonho. Sua salvação está dentro dele, heróis ..." -- Needs review
	icravalitriayell2 = "ESTOU RENOVADO! Ysera, conceda-me o favor de colocar essas criaturas imundas para descansar!" -- Needs review
	nrallbuttonmaint = "Listar por Zona" -- Needs review
	nrallbuttontak = "Táticas" -- Needs review
	nxraonyemote = "toma uma respiração profunda" -- Needs review
	nxraonyxiab = "Onyxia" -- Needs review
	nxratitle = "Naxxramas + e outras mini raides de WotLK" -- Needs review
	phratitle = "Heróicos de Pandaria" -- Needs review
	prratitle = "Raides de Pandaria" -- Needs review
	psbuttonoff = "PARAR" -- Needs review
	psbuttonon = "Iniciar"
	pseaaddonmy = "AddOn"
	pseaaddonoff = "DESLIGAR" -- Needs review
	pseaaddonok = "OK"
	pseaaddonon = "Ativar addon"
	pseaaddonon2 = "LIGAR" -- Needs review
	pseachangeall = "Trocar" -- Needs review
	pseachatlist1 = "raide"
	pseachatlist2 = "aviso de raide"
	pseachatlist3 = "oficial"
	pseachatlist4 = "grupo"
	pseachatlist5 = "guilda"
	pseachatlist6 = "dizer"
	pseachatlist7 = "gritar"
	pseachatlist8 = "si próprio" -- Needs review
	pseadisableall = "Desativar tudo"
	pseaenableall = "Ativar Tudo"
	psealeftmenu1 = "AddOn"
	psealeftmenu11 = "Rastrear após falhar"
	psealeftmenu3 = "Naxxramas" -- Needs review
	psealeftmenu31 = "Naxxramas + outras mini raides de WotLK"
	psealeftmenu4 = "Masmorras de Wotlk"
	psealeftmenu5 = "Ulduar" -- Needs review
	psealeftmenu6 = "Cidadela da Coroa de Gelo"
	psealeftmenucata = "Cata Heróico " -- Needs review
	psealeftmenucata2 = "Raides do Cata" -- Needs review
	psealeftmenupanda = "Heróicos de Panda" -- Needs review
	psealeftmenupanda2 = "Raides de Panda" -- Needs review
	psealeftmenupanda3 = "Cenários de Panda" -- Needs review
	pseamanyachtitle = "Continuar rastreando após falha"
	pseamimifailloc1 = "Robô Bum!" -- Needs review
	pseamimifailloc2 = "Ataque de Foguete" -- Needs review
	pseamimifailloc3 = "Mina!" -- Needs review
	pseamimifailloc5 = "parte falhou" -- Needs review
	pseamoduleload = "Módulo carregado:"
	pseamodulenotload = "Erro ao carregar módulo:"
	pseaoldmodules = "Módulos antigos" -- Needs review
	pseaoldmodules2 = "Módulos antigos" -- Needs review
	pseapartfailedloc = "uma parte falhou!" -- Needs review
	pseapsaddonanet = "Erro! O Addon PhoenixStyle não está instalado"
	pseapsaddonanet2 = "Você pode baixa-lo em www.phoenixstyle.com" -- Needs review
	pseareports = "- canal onde aparecerá os avisos" -- Needs review
	pseashownames = "Mostrar motivo (nome, etc) da falha da conquista" -- Needs review
	pseashowveren = "Mostrar mensagem se uma nova versão do addon for detectada na sua guild/grupo" -- Needs review
	pseasoundoptions1 = "Tocar um som quando uma conquista falhar" -- Needs review
	pseasoundoptions2 = "Tocar um som quando os requerimentos forem atingidos" -- Needs review
	pseasoundoptions3 = "Tocar um som apenas se eu precisar dessa conquista" -- Needs review
	pseasoundoptions6 = "Master imode, usar sons mesmo quando o som do jogo estiver desativado" -- Needs review
	pseatreb2 = "requerimentos completos! Acabe com o chefe agora!" -- Needs review
	pseatreb4 = "falhou!" -- Needs review
	pseatrebulda2 = "Mate o ultimo adc SÓ ENTÃO mate o chefe!" -- Needs review
	pseauierror = "Erro!" -- Needs review
	pseauierroraddonoff = "Error! O Addon está desativado - este módulo está indisponivel" -- Needs review
	pseauinomodule1 = "Erro! Módulo não instalado!" -- Needs review
	pseauinomodule2 = "Erro! Módulo escolhido não instalado!" -- Needs review
	pseaulduarkolf1 = "Adc foi morto!" -- Needs review
	pseaulduarkolf2 = "não irá completar se o chefe for morto agora!" -- Needs review
	pseaulduartitle = "Ulduar" -- Needs review
	PSFeaserver = "ru-Gordunni" -- Needs review
	psmoduletxtoff = "módulo desativado" -- Needs review
	psmoduletxton = "módulo ativado" -- Needs review
	psoldvertxt = "(versão obsoleta)" -- Needs review
	pzratitle = "Cenários de Pandaria" -- Needs review
	racolor1 = "vermelho" -- Needs review
	racolor2 = "preto" -- Needs review
	racolor3 = "amarelo" -- Needs review
	racolor5 = "verde" -- Needs review
	racolor6 = "roxo" -- Needs review
	racolorcomb = "combinação ESQUERDA UM" -- Needs review
	racredits1 = "Créditos" -- Needs review
	racredits2 = "Obrigado pela ajuda!" -- Needs review
	radatabrokervart = "Clicar = Mostrar | Esconder" -- Needs review
	radeathwingemote1 = "gire para a esquerda!" -- Needs review
	radeathwingemote2 = "gire para a direita!" -- Needs review
	raerroraddoninst = "Erro! Addon não instalado, você deve baixa-lo e instala-lo." -- Needs review
	raerrormodulereq = "Módulo adicional é requerido." -- Needs review
	raiccof = "de" -- Needs review
	raiccused = "usado" -- Needs review
	ramainbattleground = "campo de batalha" -- Needs review
	ramainbattlegroundopt = "Mostrar a lista de conquistas também em campos de batalha (se estiver habilitado para raides)" -- Needs review
	ramaintrackingtitle = "Rastreando" -- Needs review
	ramanyachtitinfo = "Quando uma conquista que estiver sendo rastreada falhar ela é bloqueada até o fim da luta. Esse módulo reinicia o bloqueio. Reinicio em" -- Needs review
	ramanyachtitinfo2 = "depois da 'mensagem de falha'. Escolha quantos resets devem ser feitos por luta e clique em 'iniciar' módulo. Este módulo é desativado após logout." -- Needs review
	ramanyachtitinfoq = "Bloqueio de rastreamento de conquista será reiniciado" -- Needs review
	ramanyachtitinfoq2 = "vezes por luta. Mudar:" -- Needs review
	ramanyplayers = "muitos jogadores" -- Needs review
	raminibuttset = "Mostrar botão no mini mapa" -- Needs review
	ramodulnotblock = "rastreio não será bloqueado" -- Needs review
	ranewversfound = "|cff00ff00Attention!|r Nova versão encontrada, é recomendável que se baixe a nova versão em http://phoenixstyle.com" -- Needs review
	ranotsure = "NÃO EXATAMENTE!" -- Needs review
	raragnaachtxt1 = "mate o chefe para pegar!" -- Needs review
	raragnaachtxt2 = "Requerimentos completos! Você tem %s seg para matar o chefe! Verifique o contador no seu BossMod" -- Needs review
	rasec = "seg." -- Needs review
	raspectext = "A Zona da luta é muito grande. Precisa-se de mais addons no grupo de raide!" -- Needs review
	ravalitnottrack = "não rastrear no modo heróico por addon" -- Needs review
	rayard = "jard" -- Needs review
	whraaddkilled1 = "O Adc foi morto!" -- Needs review
	whraaddkilled2 = "não será completado se o chefe for morto agora!" -- Needs review
	whrabrann = "Brann Barbabronze" -- Needs review
	whrabrannemo = "você quer jogar duro" -- Needs review
	whrabrannemo2 = "segurança desativada. Começando expurgo da memória e" -- Needs review
	whragundemo = "vai derramar suas tripas" -- Needs review
	whratitle = "Heróicos de Wotlk" -- Needs review

end

end

==> go.php?file=RaidAchievement6.007.zip: RaidAchievement/Localization/localization-ptBR.lua <==
﻿if GetLocale() == "ptBR" then

function psealocale()

	charakillintime = "Requerimentos completos! Mate o chefe com 3 stacks de Carga Elétrica (30 seg restando)!" -- Needs review
	charakillintime2 = "Requerimentos completos! Acabe com o chefe agora enquanto ele está com o buff (20 seg restantes)!" -- Needs review
	-- chhrbrannyell = ""
	chratitle = "Cataclysm Heróico" -- Needs review
	crraraidpartachloc1 = "Choque Estático!" -- Needs review
	crraraidpartachloc2 = "Bomba de Veneno!" -- Needs review
	crraraidpartachloc3 = "Aniquilador Arcano!" -- Needs review
	crraraidpartachloc4 = "Lança-chamas!" -- Needs review
	crratitle = "Raides do Cataclysm" -- Needs review
	icratitle = "cidadela da coroa de gelo" -- Needs review
	icravalitriayell1 = "Eu abri um portal para o Sonho. Sua salvação está dentro dele, heróis ..." -- Needs review
	icravalitriayell2 = "ESTOU RENOVADO! Ysera, conceda-me o favor de colocar essas criaturas imundas para descansar!" -- Needs review
	nrallbuttonmaint = "Listar por Zona" -- Needs review
	nrallbuttontak = "Táticas" -- Needs review
	nxraonyemote = "toma uma respiração profunda" -- Needs review
	nxraonyxiab = "Onyxia" -- Needs review
	nxratitle = "Naxxramas + e outras mini raides de WotLK" -- Needs review
	phratitle = "Heróicos de Pandaria" -- Needs review
	prratitle = "Raides de Pandaria" -- Needs review
	psbuttonoff = "PARAR" -- Needs review
	psbuttonon = "Iniciar"
	pseaaddonmy = "AddOn"
	pseaaddonoff = "DESLIGAR" -- Needs review
	pseaaddonok = "OK"
	pseaaddonon = "Ativar addon"
	pseaaddonon2 = "LIGAR" -- Needs review
	pseachangeall = "Trocar" -- Needs review
	pseachatlist1 = "raide"
	pseachatlist2 = "aviso de raide"
	pseachatlist3 = "oficial"
	pseachatlist4 = "grupo"
	pseachatlist5 = "guilda"
	pseachatlist6 = "dizer"
	pseachatlist7 = "gritar"
	pseachatlist8 = "si próprio" -- Needs review
	pseadisableall = "Desativar tudo"
	pseaenableall = "Ativar Tudo"
	psealeftmenu1 = "AddOn"
	psealeftmenu11 = "Rastrear após falhar"
	psealeftmenu3 = "Naxxramas" -- Needs review
	psealeftmenu31 = "Naxxramas + outras mini raides de WotLK"
	psealeftmenu4 = "Masmorras de Wotlk"
	psealeftmenu5 = "Ulduar" -- Needs review
	psealeftmenu6 = "Cidadela da Coroa de Gelo"
	psealeftmenucata = "Cata Heróico " -- Needs review
	psealeftmenucata2 = "Raides do Cata" -- Needs review
	psealeftmenupanda = "Heróicos de Panda" -- Needs review
	psealeftmenupanda2 = "Raides de Panda" -- Needs review
	psealeftmenupanda3 = "Cenários de Panda" -- Needs review
	pseamanyachtitle = "Continuar rastreando após falha"
	pseamimifailloc1 = "Robô Bum!" -- Needs review
	pseamimifailloc2 = "Ataque de Foguete" -- Needs review
	pseamimifailloc3 = "Mina!" -- Needs review
	pseamimifailloc5 = "parte falhou" -- Needs review
	pseamoduleload = "Módulo carregado:"
	pseamodulenotload = "Erro ao carregar módulo:"
	pseaoldmodules = "Módulos antigos" -- Needs review
	pseaoldmodules2 = "Módulos antigos" -- Needs review
	pseapartfailedloc = "uma parte falhou!" -- Needs review
	pseapsaddonanet = "Erro! O Addon PhoenixStyle não está instalado"
	pseapsaddonanet2 = "Você pode baixa-lo em www.phoenixstyle.com" -- Needs review
	pseareports = "- canal onde aparecerá os avisos" -- Needs review
	pseashownames = "Mostrar motivo (nome, etc) da falha da conquista" -- Needs review
	pseashowveren = "Mostrar mensagem se uma nova versão do addon for detectada na sua guild/grupo" -- Needs review
	pseasoundoptions1 = "Tocar um som quando uma conquista falhar" -- Needs review
	pseasoundoptions2 = "Tocar um som quando os requerimentos forem atingidos" -- Needs review
	pseasoundoptions3 = "Tocar um som apenas se eu precisar dessa conquista" -- Needs review
	pseasoundoptions6 = "Master imode, usar sons mesmo quando o som do jogo estiver desativado" -- Needs review
	pseatreb2 = "requerimentos completos! Acabe com o chefe agora!" -- Needs review
	pseatreb4 = "falhou!" -- Needs review
	pseatrebulda2 = "Mate o ultimo adc SÓ ENTÃO mate o chefe!" -- Needs review
	pseauierror = "Erro!" -- Needs review
	pseauierroraddonoff = "Error! O Addon está desativado - este módulo está indisponivel" -- Needs review
	pseauinomodule1 = "Erro! Módulo não instalado!" -- Needs review
	pseauinomodule2 = "Erro! Módulo escolhido não instalado!\r\nDownload it from http://phoenixstyle.com or curse.com" -- Needs review
	pseaulduarkolf1 = "Adc foi morto!" -- Needs review
	pseaulduarkolf2 = "não irá completar se o chefe for morto agora!" -- Needs review
	pseaulduartitle = "Ulduar" -- Needs review
	PSFeaserver = "ru-Gordunni" -- Needs review
	psmoduletxtoff = "módulo desativado" -- Needs review
	psmoduletxton = "módulo ativado" -- Needs review
	psoldvertxt = "(versão obsoleta)" -- Needs review
	pzratitle = "Cenários de Pandaria" -- Needs review
	racolor1 = "vermelho" -- Needs review
	racolor2 = "preto" -- Needs review
	racolor3 = "amarelo" -- Needs review
	racolor5 = "verde" -- Needs review
	racolor6 = "roxo" -- Needs review
	racolorcomb = "combinação ESQUERDA UM" -- Needs review
	racredits1 = "Créditos" -- Needs review
	racredits2 = "Obrigado pela ajuda!" -- Needs review
	radatabrokervart = "Clicar = Mostrar | Esconder" -- Needs review
	radeathwingemote1 = "gire para a esquerda!" -- Needs review
	radeathwingemote2 = "gire para a direita!" -- Needs review
	raerroraddoninst = "Erro! Addon não instalado, você deve baixa-lo e instala-lo." -- Needs review
	raerrormodulereq = "Módulo adicional é requerido." -- Needs review
	raiccof = "de" -- Needs review
	raiccused = "usado" -- Needs review
	ramainbattleground = "campo de batalha" -- Needs review
	ramainbattlegroundopt = "Mostrar a lista de conquistas também em campos de batalha (se estiver habilitado para raides)" -- Needs review
	ramaintrackingtitle = "Rastreando" -- Needs review
	ramanyachtitinfo = "Quando uma conquista que estiver sendo rastreada falhar ela é bloqueada até o fim da luta. Esse módulo reinicia o bloqueio. Reinicio em" -- Needs review
	ramanyachtitinfo2 = "depois da 'mensagem de falha'. Escolha quantos resets devem ser feitos por luta e clique em 'iniciar' módulo. Este módulo é desativado após logout." -- Needs review
	ramanyachtitinfoq = "Bloqueio de rastreamento de conquista será reiniciado" -- Needs review
	ramanyachtitinfoq2 = "vezes por luta. Mudar:" -- Needs review
	ramanyplayers = "muitos jogadores" -- Needs review
	raminibuttset = "Mostrar botão no mini mapa" -- Needs review
	ramodulnotblock = "rastreio não será bloqueado" -- Needs review
	ranewversfound = "|cff00ff00Attention!|r Nova versão encontrada, é recomendável que se baixe a nova versão em http://phoenixstyle.com" -- Needs review
	ranotsure = "NÃO EXATAMENTE!" -- Needs review
	raragnaachtxt1 = "mate o chefe para pegar!" -- Needs review
	raragnaachtxt2 = "Requerimentos completos! Você tem %s seg para matar o chefe! Verifique o contador no seu BossMod" -- Needs review
	rasec = "seg." -- Needs review
	raspectext = "A Zona da luta é muito grande. Precisa-se de mais addons no grupo de raide!" -- Needs review
	ravalitnottrack = "não rastrear no modo heróico por addon" -- Needs review
	rayard = "jard" -- Needs review
	whraaddkilled1 = "O Adc foi morto!" -- Needs review
	whraaddkilled2 = "não será completado se o chefe for morto agora!" -- Needs review
	whrabrann = "Brann Barbabronze" -- Needs review
	whrabrannemo = "você quer jogar duro" -- Needs review
	whrabrannemo2 = "segurança desativada. Começando expurgo da memória e" -- Needs review
	whragundemo = "vai derramar suas tripas" -- Needs review
	whratitle = "Heróicos de Wotlk" -- Needs review

end

end
